@@ -3,25 +3,20 @@ package Module::Release::Git;
 
 use strict;
 use warnings;
-use base qw(Exporter Module::Release);
+use base qw(Exporter);
 
-our @EXPORT = qw(check_cvs cvs_tag);
+our @EXPORT = qw(check_cvs cvs_tag make_cvs_tag);
 
-our $VERSION = '0.10_01';
+our $VERSION = '0.10_02';
 
 =head1 NAME
 
-Module::Release::Git - Use Git instead of CVS with Module::Release
+Module::Release::Git - Use Git with Module::Release
 
 =head1 SYNOPSIS
 
-In F<.releaserc>
-
-  release_subclass Module::Release::Git
-
-In your subclasses of Module::Release:
-
-  use base qw(Module::Release::Git);
+The release script automatically loads this module if it sees a 
+F<.git> directory. The module exports check_cvs, cvs_tag, and make_cvs_tag.
 
 =head1 DESCRIPTION
 
@@ -35,9 +30,9 @@ using Exporter.
 
 This module depends on the external git binary (so far).
 
-=cut
+=over 4
 
-=head2 C<check_cvs()>
+=item C<check_cvs()>
 
 Check the state of the Git repository.
 
@@ -51,19 +46,21 @@ sub check_cvs
 	
 	my $git_status = $self->run('git status 2>&1');
 		
+	no warnings 'uninitialized';
+
 	my $branch = $git_status =~ /^# On branch (\w+)/;
 	
 	my $up_to_date = $git_status =~ /^nothing to commit \(working directory clean\)/m;
 	
-	die "\nERROR: Git is not up-to-date: Can't release files\n\n$git_status\n"
+	$self->_die( "\nERROR: Git is not up-to-date: Can't release files\n\n$git_status\n" )
 		unless $up_to_date;
 	
-	$self->_print( "Git up-to-date\n" );
+	$self->_print( "Git up-to-date on branch $branch\n" );
 	
 	return 1;
 	}
 
-=head2 C<cvs_tag(TAG)>
+=item C<cvs_tag(TAG)>
 
 Tag the release in local Git.
 
@@ -80,12 +77,25 @@ sub cvs_tag
 	return 1;
 	}
 
-sub _print
+=item make_cvs_tag
+
+By default, examines the name of the remote file
+(i.e. F<Foo-Bar-0.04.tar.gz>) and constructs a tag string like
+C<RELEASE_0_04> from it.  Override this method if you want to use a
+different tagging scheme, or don't even call it.
+
+=cut
+
+sub make_cvs_tag
 	{
 	my $self = shift;
+	my( $major, $minor ) = $self->{remote}
+		=~ /(\d+) \. (\d+(?:_\d+)?) (?:\. tar \. gz)? $/xg;
 
-	print @_;
+	return "RELEASE_${major}_${minor}";
 	}
+
+=back
 	
 =head1 TO DO
 
@@ -113,7 +123,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007, brian d foy, All Rights Reserved.
+Copyright (c) 2007-2008, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
